pytest-trio
===========

.. image:: https://travis-ci.org/python-trio/pytest-trio.svg?branch=master
    :target: https://travis-ci.org/python-trio/pytest-trio

.. image:: https://ci.appveyor.com/api/projects/status/aq0pklx7hanx031x?svg=true
    :target: https://ci.appveyor.com/project/touilleMan/pytest-trio

.. image:: https://codecov.io/gh/python-trio/pytest-trio/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/python-trio/pytest-trio

Welcome to `pytest-trio <https://github.com/python-trio/pytest-trio>`__!

Pytest plugin for trio

License: Your choice of MIT or Apache License 2.0
